==> BCTLSNetwork_6_2025-11-19_11.03.40.jar: ca/tecreations/apps/deploy/Data.java <==
package ca.tecreations.apps.deploy;
import java.awt.Color;
import java.util.Random;

public class Data {
    
    
    public static String DEBUG_SSL = "debug.ssl";
    public static String MAIN_CLASS = "main.class";
    public static String MAKE_SECURE = "make.secure";
    public static String MANIFEST_ATTRIBUTES = "manifest.attributes";
    public static String OUTPUT_APPEND_DATE = "output.append.date";
    public static String OUTPUT_APPEND_TIME = "output.append.time";
    public static String OUTPUT_PREFIX = "output.prefix";
    public static String PROJECT_CREATE_JAR = "project.create.jar";
    public static String PROJECT_INCLUDE_CLASSES = "project.include.classes";
    public static String PROJECT_INCLUDE_UNSPECIFIED = "project.include.unspecified";
    public static String PROJECT_INCLUDE_JARS = "project.include.jars";
    public static String PROJECT_INCLUDE_SOURCES = "project.include.sources";
    public static String PROJECT_PATH = "project.path";
    public static String PROJECT_PATHS_INCLUDES = "project.paths.includes";
    public static String PROJECT_PATHS_EXCLUDES = "project.paths.excludes";
    public static String REMOTE_ACTIVE = "remote.active";
    public static String REMOTE_HOST = "remote.host";
    public static String REMOTE_PATH = "remote.path";
    public static String REMOTE_PORT = "remote.port";
    public static String REMOTE_SHOW_PASS = "remote.show.pass";
    public static String SIGNING_ACTIVE = "signing.active";
    public static String SIGNING_ALIAS = "signing.alias";
    public static String SIGNING_KEY_PASS = "signing.key.pass";
    public static String SIGNING_KEYSOTORE_PASS = "signing.keysotore.pass";
    public static String SIGNING_KEYSTORE = "signing.keystore";
    public static String SIGNING_KEYSTORE_PASS = "signing.keystore.pass";
    public static String SIGNING_PREFIX = "signing.prefix";
    public static String SIGNING_SHOW_PASS = "signing.show.pass";
    public static String SIGNING_TSA = "signing.tsa";
    public static String WINDOW_HEIGHT = "window.height";
    public static String WINDOW_WIDTH = "window.width";
    public static String WINDOW_X = "window.x";
    public static String WINDOW_Y = "window.y";
    
    public static Random RANDOM = new Random();

    public static Color getRandomColor() {
        return new Color(RANDOM.nextFloat(),RANDOM.nextFloat(),RANDOM.nextFloat());
    }
}

==> BCTLSNetwork_19_2025-12-24_19.14.10.jar: ca/tecreations/apps/deploy/Data.java <==
package ca.tecreations.apps.deploy;
import java.awt.Color;
import java.util.Random;

public class Data {
    
    
    public static String DEBUG_SSL = "debug.ssl";
    public static String MAIN_CLASS = "main.class";
    public static String MAKE_SECURE = "make.secure";
    public static String MANIFEST_ATTRIBUTES = "manifest.attributes";
    public static String OUTPUT_APPEND_DATE = "output.append.date";
    public static String OUTPUT_APPEND_TIME = "output.append.time";
    public static String OUTPUT_PREFIX = "output.prefix";
    public static String PROJECT_CREATE_JAR = "project.create.jar";
    public static String PROJECT_INCLUDE_CLASSES = "project.include.classes";
    public static String PROJECT_INCLUDE_UNSPECIFIED = "project.include.unspecified";
    public static String PROJECT_INCLUDE_JARS = "project.include.jars";
    public static String PROJECT_INCLUDE_SOURCES = "project.include.sources";
    public static String PROJECT_NAME = "project.name";
    public static String PROJECT_PATHS_INCLUDES = "project.paths.includes";
    public static String PROJECT_PATHS_EXCLUDES = "project.paths.excludes";
    public static String REMOTE_ACTIVE = "remote.active";
    public static String REMOTE_HOST = "remote.host";
    public static String REMOTE_PATH = "remote.path";
    public static String REMOTE_PORT = "remote.port";
    public static String REMOTE_SHOW_PASS = "remote.show.pass";
    public static String SIGNING_ACTIVE = "signing.active";
    public static String SIGNING_ALIAS = "signing.alias";
    public static String SIGNING_KEY_PASS = "signing.key.pass";
    public static String SIGNING_KEYSOTORE_PASS = "signing.keysotore.pass";
    public static String SIGNING_KEYSTORE = "signing.keystore";
    public static String SIGNING_KEYSTORE_PASS = "signing.keystore.pass";
    public static String SIGNING_PREFIX = "signing.prefix";
    public static String SIGNING_SHOW_PASS = "signing.show.pass";
    public static String SIGNING_TSA = "signing.tsa";
    public static String WINDOW_HEIGHT = "window.height";
    public static String WINDOW_WIDTH = "window.width";
    public static String WINDOW_X = "window.x";
    public static String WINDOW_Y = "window.y";
    
    public static Random RANDOM = new Random();

    public static Color getRandomColor() {
        return new Color(RANDOM.nextFloat(),RANDOM.nextFloat(),RANDOM.nextFloat());
    }
}
